@@ -272,7 +272,7 @@ def handle_prerequisites(s3_base_module_link, module_name):
         response = urllib.request.urlopen(s3_base_module_link + '/' + module_name + '/' + module_name + '.req')
         print ("2")
         requirements_file = response.read()
-        print ("3")
+        print ("3", "requirements_file", requirements_file)
         requirements_names = requirements_file.split("\n")
         print ("This module requires the following packages to be installed:")
         for requirement in requirements_names:
