@@ -1,3 +1,6 @@
+from __future__ import absolute_import
+from builtins import str
+from builtins import object
 import inspect
 import logging
 import os
@@ -5,9 +8,9 @@ import sys
 import time
 import traceback
 
-from scheduler import ThreadedScheduler, method
-from utils import load_class_from_name
-import basemodule
+from .scheduler import ThreadedScheduler, method
+from .utils import load_class_from_name
+from . import basemodule
 
 
 class TaskManager(object):
@@ -32,7 +35,7 @@ class TaskManager(object):
         modules = self.load_modules(modules_folder)
 
         # Setup Modules
-        for module in modules.values():
+        for module in list(modules.values()):
             # Initialize Module
             c = self.init_module(module['cls'])
             # Schedule Module
@@ -73,7 +76,7 @@ class TaskManager(object):
                 modules = self.load_modules(modules_folder)
 
                 # Setup Modules
-                for module in modules.values():
+                for module in list(modules.values()):
                     # Initialize Module
                     c = self.init_module(module['cls'])
                     # Schedule Module
@@ -121,7 +124,7 @@ class TaskManager(object):
                 mod_modification_time_str = str(mod_modification_time)
                 self.log.info("Py file found: %s" % modname)
 
-                modules_list = [x.lower() for x in self.tasks.keys()]
+                modules_list = [x.lower() for x in list(self.tasks.keys())]
                 if modname in modules_list:
                     if self.tasks[modname]['modification_time'] == mod_modification_time_str:
                         self.log.info("Module '{0}' already loaded".format(modname))
@@ -152,7 +155,7 @@ class TaskManager(object):
                     # Only attempt to load classes that are infact classes but not the base Module class
                     self.log.debug("Checking " + str(modname) + " Attribute " + str(attrname))
 
-                    if inspect.isclass(attr) and isModule(attr) and attr != basemodule.Module:
+                    if inspect.isclass(attr) and isModule(attr) and attr != basemodule.Module and attrname != "Module":
                         # Get class name
                         fqcn = '.'.join([modname, attrname])
                         self.log.info("Module loaded : " + fqcn)
@@ -202,7 +205,7 @@ class TaskManager(object):
             return
 
         # Get Module schedule
-        for name, schedule in c.get_schedule().items():
+        for name, schedule in list(c.get_schedule().items()):
             # Get scheduler args
             func, args, splay, interval = schedule
 
@@ -233,7 +236,7 @@ class TaskManager(object):
 
         self.log.info('Stopped task scheduler.')
 
-        for key, task in self.tasks.iteritems():
+        for key, task in self.tasks.items():
             try:
                 self.scheduler.cancel(task['task'])
                 # Log
